Sophie

Sophie

distrib > Mageia > 5 > x86_64 > media > core-updates-src > by-pkgid > 09496ae16bc397e8e71f8ecc490ae5cf > files > 3

apache-mod_fcgid-2.3.9-4.1.mga5.src.rpm

Index: mod_fcgid-2.3.9/modules/fcgid/mod_fcgid.c
===================================================================
--- mod_fcgid-2.3.9.orig/modules/fcgid/mod_fcgid.c
+++ mod_fcgid-2.3.9/modules/fcgid/mod_fcgid.c
@@ -155,9 +155,15 @@ static void fcgid_add_cgi_vars(request_r
                  * consistent with legacy mod_fcgid behavior and mod_fastcgi
                  * prior to 2.4.7
                  */
-                apr_table_setn(r->subprocess_env, *hdr, val);
-                /* standard munging of header name (upcase, HTTP_, etc.) */
-                apr_table_setn(r->subprocess_env, http2env(r->pool, *hdr), val);
+                /* boo#988492 httpoxy don't set HTTP_PROXY */
+                if ( strcasecmp(*hdr, "HTTP_PROXY") != 0 && strcasecmp(*hdr, "HTTP-PROXY") != 0) {
+                    apr_table_setn(r->subprocess_env, *hdr, val);
+                }
+                /* boo#988492 httpoxy don't set HTTP_PROXY */
+                if ( strcasecmp(*hdr, "PROXY") != 0 ) {
+                    /* standard munging of header name (upcase, HTTP_, etc.) */
+                    apr_table_setn(r->subprocess_env, http2env(r->pool, *hdr), val);
+                }
             }
         }
     }